==> qttranslations-opensource-src_5.0.2.orig.tar.xz: qttranslations-opensource-src-5.0.2/translations/qtmultimedia_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>AudioCaptureSession</name>
    <message>
        <source>RAW file format</source>
        <translation>RAW-Dateiformat</translation>
    </message>
    <message>
        <source>WAV file format</source>
        <translation>WAV-Dateiformat</translation>
    </message>
</context>
<context>
    <name>AudioEncoderControl</name>
    <message>
        <source>PCM audio data</source>
        <translation>PCM-Audiodaten</translation>
    </message>
</context>
<context>
    <name>CameraBinImageCapture</name>
    <message>
        <source>Camera not ready</source>
        <translation>Kamera nicht bereit</translation>
    </message>
</context>
<context>
    <name>CameraBinImageEncoder</name>
    <message>
        <source>JPEG image</source>
        <translation>JPEG-Bild</translation>
    </message>
</context>
<context>
    <name>CameraBinRecorder</name>
    <message>
        <source>QMediaRecorder::pause() is not supported by camerabin2.</source>
        <translation>QMediaRecorder::pause() wird von camerabin2 nicht unterstützt.</translation>
    </message>
    <message>
        <source>Service has not been started</source>
        <translation>Der Dienst wurde nicht gestartet</translation>
    </message>
</context>
<context>
    <name>CameraBinSession</name>
    <message>
        <source>Camera error</source>
        <translation>Kamerafehler</translation>
    </message>
</context>
<context>
    <name>MFPlayerSession</name>
    <message>
        <source>Invalid stream source.</source>
        <translation>Ungültige Datenstromquelle.</translation>
    </message>
    <message>
        <source>Attempting to play invalid Qt resource.</source>
        <translation>Es wurde versucht, eine ungültige Qt-Ressource abzuspielen.</translation>
    </message>
    <message>
        <source>The system cannot find the file specified.</source>
        <translation>Das System kann die angegebene Datei nicht finden.</translation>
    </message>
    <message>
        <source>The specified server could not be found.</source>
        <translation>Der angegebene Server konnte nicht gefunden werden.</translation>
    </message>
    <message>
        <source>Unsupported media type.</source>
        <translation>Nicht unterstützter Medientyp.</translation>
    </message>
    <message>
        <source>Failed to load source.</source>
        <translation>Die Quelle konnte nicht geladen werden.</translation>
    </message>
    <message>
        <source>Cannot create presentation descriptor.</source>
        <translation>Der Präsentationsdeskriptor kann nicht erzeugt werden.</translation>
    </message>
    <message>
        <source>Failed to get stream count.</source>
        <translation>Anzahl der Datenströme konnte nicht bestimmt werden.</translation>
    </message>
    <message>
        <source>Failed to create topology.</source>
        <translation>Topologie konnte nicht erzeugt werden.</translation>
    </message>
    <message>
        <source>Unable to play any stream.</source>
        <translation>Es konnte kein Datenstrom abgespielt werden.</translation>
    </message>
    <message>
        <source>Unable to play.</source>
        <translation>Abspielen nicht möglich.</translation>
    </message>
    <message>
        <source>Failed to set topology.</source>
        <translation>Topologie konnte nicht gesetzt werden.</translation>
    </message>
    <message>
        <source>Unknown stream type.</source>
        <translation>Unbekannter Datenstromtyp.</translation>
    </message>
    <message>
        <source>Failed to stop.</source>
        <translation>Stoppen nicht möglich.</translation>
    </message>
    <message>
        <source>Failed to pause.</source>
        <translation>Pausieren nicht möglich.</translation>
    </message>
    <message>
        <source>Unable to create mediasession.</source>
        <translation>Es konnte keine Medien-Session erzeugt werden.</translation>
    </message>
    <message>
        <source>Unable to pull session events.</source>
        <translation>Events der Sitzung konnten nicht abgeholt werden.</translation>
    </message>
    <message>
        <source>Failed to seek.</source>
        <translation>Positionierung fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Media session non-fatal error.</source>
        <translation>Unkritischer Fehler der Medien-Session.</translation>
    </message>
    <message>
        <source>Media session serious error.</source>
        <translation>Kritischer Fehler der Medien-Session.</translation>
    </message>
    <message>
        <source>Unsupported media, a codec is missing.</source>
        <translation>Nicht unterstütztes Medium; es fehlt ein Codec.</translation>
    </message>
    <message>
        <source>failed to start playback</source>
        <translation>Playback konnte nicht gestartet werden</translation>
    </message>
</context>
<context>
    <name>PLSParser</name>
    <message>
        <source>Error parsing playlist: %1, expected count = %2</source>
        <translation>Fehler beim Auswerten der Abspielliste %1, erwartete Anzahl = %2</translation>
    </message>
    <message>
        <source>Error parsing playlist at line[%1], expected version = 2</source>
        <translation>Fehler beim Auswerten der Abspielliste bei Zeile [%1], erwartete Version = 2</translation>
    </message>
    <message>
        <source>Error parsing playlist at line[%1]:%2</source>
        <translation>Fehler beim Auswerten der Abspielliste bei Zeile [%1]:%2</translation>
    </message>
    <message>
        <source>File%1</source>
        <translation>Datei%1</translation>
    </message>
    <message>
        <source>Title%1</source>
        <translation>Titel%1</translation>
    </message>
    <message>
        <source>Length%1</source>
        <translation>Länge%1</translation>
    </message>
</context>
<context>
    <name>QAudioDecoder</name>
    <message>
        <source>The QAudioDecoder object does not have a valid service</source>
        <translation>Das QAudioDecoder-Objekt hat keinen gültigen Dienst</translation>
    </message>
</context>
<context>
    <name>QCamera</name>
    <message>
        <source>The camera service is missing</source>
        <translation>Der Kameradienst fehlt</translation>
    </message>
</context>
<context>
    <name>QCameraImageCapture</name>
    <message>
        <source>Device does not support images capture.</source>
        <translation>Das Gerät unterstützt das Aufnehmen von Bildern nicht.</translation>
    </message>
</context>
<context>
    <name>QDeclarativeAudio</name>
    <message>
        <source>volume should be between 0.0 and 1.0</source>
        <translation>Lautstärke sollte zwischen 0.0 und 1.0 liegen</translation>
    </message>
</context>
<context>
    <name>QGstreamerAudioDecoderSession</name>
    <message>
        <source>Cannot play stream of type: &lt;unknown&gt;</source>
        <translation>Datenstrom des Typs &lt;unbekannt&gt; kann nicht abgespielt werden</translation>
    </message>
</context>
<context>
    <name>QGstreamerAudioEncode</name>
    <message>
        <source>Raw PCM audio</source>
        <translation>Raw-PCM-Audio</translation>
    </message>
</context>
<context>
    <name>QGstreamerAudioInputSelector</name>
    <message>
        <source>System default device</source>
        <translation>System-Vorgabegerät</translation>
    </message>
</context>
<context>
    <name>QGstreamerCameraControl</name>
    <message>
        <source>State not supported.</source>
        <translation>nicht unterstützter Zustand.</translation>
    </message>
</context>
<context>
    <name>QGstreamerCaptureSession</name>
    <message>
        <source>Could not create an audio source element</source>
        <translation>Das Audio-Quellelement konnte nicht erstellt werden</translation>
    </message>
    <message>
        <source>Failed to build media capture pipeline.</source>
        <translation>Es konnte keine Medien-Aufnahme-Pipeline erstellt werden.</translation>
    </message>
</context>
<context>
    <name>QGstreamerImageCaptureControl</name>
    <message>
        <source>Not ready to capture</source>
        <translation>Nicht aufnahmebereit</translation>
    </message>
</context>
<context>
    <name>QGstreamerImageEncode</name>
    <message>
        <source>JPEG image encoder</source>
        <translation>JPEG-Bild-Kodierer</translation>
    </message>
</context>
<context>
    <name>QGstreamerPlayerControl</name>
    <message>
        <source>Attempting to play invalid Qt resource</source>
        <translation>Es wurde versucht, eine ungültige Qt-Ressource abzuspielen</translation>
    </message>
    <message>
        <source>Attempting to play invalid user stream</source>
        <translation>Es wurde versucht, einen ungültigen Nutzer-Datenstrom abzuspielen</translation>
    </message>
</context>
<context>
    <name>QGstreamerPlayerSession</name>
    <message>
        <source>Cannot play stream of type: &lt;unknown&gt;</source>
        <translation>Datenstrom des Typs &lt;unbekannt&gt; kann nicht abgespielt werden</translation>
    </message>
    <message>
        <source>UDP source timeout</source>
        <translation>Zeitüberschreitung bei UDP-Quelle</translation>
    </message>
    <message>
        <source>Media is loaded as a playlist</source>
        <translation>Medien als Abspielliste geladen</translation>
    </message>
</context>
<context>
    <name>QGstreamerRecorderControl</name>
    <message>
        <source>Service has not been started</source>
        <translation>Der Dienst wurde nicht gestartet</translation>
    </message>
    <message>
        <source>Not compatible codecs and container format.</source>
        <translation>Keine kompatiblen Codecs und Container-Formate.</translation>
    </message>
</context>
<context>
    <name>QGstreamerVideoInputDeviceControl</name>
    <message>
        <source>Main camera</source>
        <translation>Hauptkamera</translation>
    </message>
    <message>
        <source>Front camera</source>
        <translation>Vordere Kamera</translation>
    </message>
</context>
<context>
    <name>QMediaPlayer</name>
    <message>
        <source>The QMediaPlayer object does not have a valid service</source>
        <translation>Das QMediaPlayer-Objekt hat keinen gültigen Dienst</translation>
    </message>
</context>
<context>
    <name>QMediaPlaylist</name>
    <message>
        <source>Could not add items to read only playlist.</source>
        <translation>Konnte keine Elemente zu schreibgeschützter Abspielliste hinzufügen</translation>
    </message>
    <message>
        <source>Playlist format is not supported</source>
        <translation>Nicht unterstütztes Format der Abspielliste</translation>
    </message>
    <message>
        <source>The file could not be accessed.</source>
        <translation>Es konnte nicht auf die Datei zugegriffen werden.</translation>
    </message>
    <message>
        <source>Playlist format is not supported.</source>
        <translation>Nicht unterstütztes Format der Abspielliste</translation>
    </message>
</context>
<context>
    <name>QMultimediaDeclarativeModule</name>
    <message>
        <source>CameraCapture is provided by Camera</source>
        <translation>CameraCapture wird von Camera bereitgestellt</translation>
    </message>
    <message>
        <source>CameraRecorder is provided by Camera</source>
        <translation>CameraRecorder wird von Camera bereitgestellt</translation>
    </message>
    <message>
        <source>CameraExposure is provided by Camera</source>
        <translation>CameraExposure wird von Camera bereitgestellt</translation>
    </message>
    <message>
        <source>CameraFocus is provided by Camera</source>
        <translation>CameraFocus wird von Camera bereitgestellt</translation>
    </message>
    <message>
        <source>CameraFlash is provided by Camera</source>
        <translation>CameraFlash wird von Camera bereitgestellt</translation>
    </message>
    <message>
        <source>CameraImageProcessing is provided by Camera</source>
        <translation>CameraImageProcessing wird von Camera bereitgestellt</translation>
    </message>
</context>
<context>
    <name>QPlaylistFileParser</name>
    <message>
        <source>%1 does not exist</source>
        <translation>%1 existiert nicht</translation>
    </message>
</context>
<context>
    <name>QPlaylistFileParserPrivate</name>
    <message>
        <source>%1 playlist type is unknown</source>
        <translation>Unbekannter Typ der Abspielliste %1</translation>
    </message>
    <message>
        <source>invalid line in playlist file</source>
        <translation>ungültige Zeile in Abspielliste</translation>
    </message>
    <message>
        <source>Empty file provided</source>
        <translation>Leere Datei angegeben</translation>
    </message>
</context>
</TS>

==> qttranslations-opensource-src_5.2.1.orig.tar.xz: qttranslations-opensource-src-5.2.1/translations/qtmultimedia_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>AudioContainerControl</name>
    <message>
        <source>RAW (headerless) file format</source>
        <translation>RAW-Dateiformat (ohne Header)</translation>
    </message>
    <message>
        <source>WAV file format</source>
        <translation>WAV-Dateiformat</translation>
    </message>
</context>
<context>
    <name>AudioEncoderControl</name>
    <message>
        <source>Linear PCM audio data</source>
        <translation>PCM-Audiodaten (linear)</translation>
    </message>
</context>
<context>
    <name>BbCameraAudioEncoderSettingsControl</name>
    <message>
        <source>No compression</source>
        <translation>Keine Kompression</translation>
    </message>
    <message>
        <source>AAC compression</source>
        <translation>AAC-Kompression</translation>
    </message>
    <message>
        <source>PCM uncompressed</source>
        <translation>Unkomprimiertes PCM</translation>
    </message>
</context>
<context>
    <name>BbCameraMediaRecorderControl</name>
    <message>
        <source>Unable to retrieve mute status</source>
        <translation>Status der Stummschaltung kann nicht bestimmt werden</translation>
    </message>
    <message>
        <source>Unable to retrieve audio input volume</source>
        <translation>Lautstärke des Audio-Eingangs kann nicht bestimmt werden</translation>
    </message>
    <message>
        <source>Unable to set mute status</source>
        <translation>Status der Stummschaltung kann nicht gesetzt werden</translation>
    </message>
    <message>
        <source>Unable to set audio input volume</source>
        <translation>Lautstärke des Audio-Eingangs kann nicht gesetzt werden</translation>
    </message>
</context>
<context>
    <name>BbCameraSession</name>
    <message>
        <source>Camera provides image in unsupported format</source>
        <translation>Die Kamera liefert Bilddaten in einem nicht unterstützten Format</translation>
    </message>
    <message>
        <source>Could not load JPEG data from frame</source>
        <translation>Es konnten keine JPEG-Daten vom Bild geladen werden</translation>
    </message>
    <message>
        <source>Camera not ready</source>
        <translation>Kamera nicht bereit</translation>
    </message>
    <message>
        <source>Unable to apply video settings</source>
        <translation>Die Videoeinstellungen können nicht vorgenommen werden</translation>
    </message>
    <message>
        <source>Could not open destination file:
%1</source>
        <translation>Die Zieldatei konnte nicht geöffnet werden:
%1</translation>
    </message>
    <message>
        <source>Unable to open camera</source>
        <translation>Die Kamera kann nicht geöffnet werden</translation>
    </message>
    <message>
        <source>Unable to retrieve native camera orientation</source>
        <translation>Die gerätespezifische Ausrichtung der Kamera kann nicht bestimmt werden</translation>
    </message>
    <message>
        <source>Unable to close camera</source>
        <translation>Die Kamera kann nicht geschlossen werden</translation>
    </message>
    <message>
        <source>Unable to start video recording</source>
        <translation>Die Videoaufaufzeichnung kann nicht gestartet werden</translation>
    </message>
    <message>
        <source>Unable to stop video recording</source>
        <translation>Die Videoaufaufzeichnung kann nicht angehalten werden</translation>
    </message>
</context>
<context>
    <name>BbCameraVideoEncoderSettingsControl</name>
    <message>
        <source>No compression</source>
        <translation>Keine Kompression</translation>
    </message>
    <message>
        <source>AVC1 compression</source>
        <translation>AVC1-Kompression</translation>
    </message>
    <message>
        <source>H264 compression</source>
        <translation>H264-Kompression</translation>
    </message>
</context>
<context>
    <name>BbImageEncoderControl</name>
    <message>
        <source>JPEG image</source>
        <translation>JPEG-Bild</translation>
    </message>
</context>
<context>
    <name>BbVideoDeviceSelectorControl</name>
    <message>
        <source>Front Camera</source>
        <translation>Vordere Kamera</translation>
    </message>
    <message>
        <source>Rear Camera</source>
        <translation>Hintere Kamera</translation>
    </message>
    <message>
        <source>Desktop Camera</source>
        <translation>Tischkamera</translation>
    </message>
</context>
<context>
    <name>CameraBinImageCapture</name>
    <message>
        <source>Camera not ready</source>
        <translation>Kamera nicht bereit</translation>
    </message>
</context>
<context>
    <name>CameraBinImageEncoder</name>
    <message>
        <source>JPEG image</source>
        <translation>JPEG-Bild</translation>
    </message>
</context>
<context>
    <name>CameraBinRecorder</name>
    <message>
        <source>QMediaRecorder::pause() is not supported by camerabin2.</source>
        <translation>QMediaRecorder::pause() wird von camerabin2 nicht unterstützt.</translation>
    </message>
    <message>
        <source>Service has not been started</source>
        <translation>Der Dienst wurde nicht gestartet</translation>
    </message>
</context>
<context>
    <name>CameraBinSession</name>
    <message>
        <source>Camera error</source>
        <translation>Kamerafehler</translation>
    </message>
</context>
<context>
    <name>MFPlayerSession</name>
    <message>
        <source>Invalid stream source.</source>
        <translation>Ungültige Datenstromquelle.</translation>
    </message>
    <message>
        <source>Attempting to play invalid Qt resource.</source>
        <translation>Es wurde versucht, eine ungültige Qt-Ressource abzuspielen.</translation>
    </message>
    <message>
        <source>The system cannot find the file specified.</source>
        <translation>Das System kann die angegebene Datei nicht finden.</translation>
    </message>
    <message>
        <source>The specified server could not be found.</source>
        <translation>Der angegebene Server konnte nicht gefunden werden.</translation>
    </message>
    <message>
        <source>Unsupported media type.</source>
        <translation>Nicht unterstützter Medientyp.</translation>
    </message>
    <message>
        <source>Failed to load source.</source>
        <translation>Die Quelle konnte nicht geladen werden.</translation>
    </message>
    <message>
        <source>Cannot create presentation descriptor.</source>
        <translation>Der Präsentationsdeskriptor kann nicht erzeugt werden.</translation>
    </message>
    <message>
        <source>Failed to get stream count.</source>
        <translation>Anzahl der Datenströme konnte nicht bestimmt werden.</translation>
    </message>
    <message>
        <source>Failed to create topology.</source>
        <translation>Topologie konnte nicht erzeugt werden.</translation>
    </message>
    <message>
        <source>Unable to play any stream.</source>
        <translation>Es konnte kein Datenstrom abgespielt werden.</translation>
    </message>
    <message>
        <source>Unable to play.</source>
        <translation>Abspielen nicht möglich.</translation>
    </message>
    <message>
        <source>Failed to set topology.</source>
        <translation>Topologie konnte nicht gesetzt werden.</translation>
    </message>
    <message>
        <source>Unknown stream type.</source>
        <translation>Unbekannter Datenstromtyp.</translation>
    </message>
    <message>
        <source>Failed to stop.</source>
        <translation>Stoppen nicht möglich.</translation>
    </message>
    <message>
        <source>Failed to pause.</source>
        <translation>Pausieren nicht möglich.</translation>
    </message>
    <message>
        <source>Unable to create mediasession.</source>
        <translation>Es konnte keine Medien-Session erzeugt werden.</translation>
    </message>
    <message>
        <source>Unable to pull session events.</source>
        <translation>Events der Sitzung konnten nicht abgeholt werden.</translation>
    </message>
    <message>
        <source>Failed to seek.</source>
        <translation>Positionierung fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Media session non-fatal error.</source>
        <translation>Unkritischer Fehler der Medien-Session.</translation>
    </message>
    <message>
        <source>Media session serious error.</source>
        <translation>Kritischer Fehler der Medien-Session.</translation>
    </message>
    <message>
        <source>Unsupported media, a codec is missing.</source>
        <translation>Nicht unterstütztes Medium; es fehlt ein Codec.</translation>
    </message>
    <message>
        <source>failed to start playback</source>
        <translation>Playback konnte nicht gestartet werden</translation>
    </message>
</context>
<context>
    <name>PLSParser</name>
    <message>
        <source>Error parsing playlist: %1, expected count = %2</source>
        <translation>Fehler beim Auswerten der Abspielliste %1, erwartete Anzahl = %2</translation>
    </message>
    <message>
        <source>Error parsing playlist at line[%1], expected version = 2</source>
        <translation>Fehler beim Auswerten der Abspielliste bei Zeile [%1], erwartete Version = 2</translation>
    </message>
    <message>
        <source>Error parsing playlist at line[%1]:%2</source>
        <translation>Fehler beim Auswerten der Abspielliste bei Zeile [%1]:%2</translation>
    </message>
    <message>
        <source>File%1</source>
        <translation>Datei%1</translation>
    </message>
    <message>
        <source>Title%1</source>
        <translation>Titel%1</translation>
    </message>
    <message>
        <source>Length%1</source>
        <translation>Länge%1</translation>
    </message>
</context>
<context>
    <name>QAndroidAudioEncoderSettingsControl</name>
    <message>
        <source>Adaptive Multi-Rate Narrowband (AMR-NB) audio codec</source>
        <translation>Adaptive Multi-Rate Narrowband (AMR-NB) audio codec</translation>
    </message>
    <message>
        <source>Adaptive Multi-Rate Wideband (AMR-WB) audio codec</source>
        <translation>Adaptive Multi-Rate Wideband (AMR-WB) audio codec</translation>
    </message>
    <message>
        <source>AAC Low Complexity (AAC-LC) audio codec</source>
        <translation>AAC Low Complexity (AAC-LC) audio codec</translation>
    </message>
</context>
<context>
    <name>QAndroidCameraSession</name>
    <message>
        <source>Camera not ready</source>
        <translation>Kamera nicht bereit</translation>
    </message>
    <message>
        <source>Drive mode not supported</source>
        <extracomment>Drive mode is the camera&apos;s shutter mode, for example single shot, continuos exposure, etc.</extracomment>
        <translation>Auslösemodus wird nicht unterstützt</translation>
    </message>
    <message>
        <source>Could not open destination file: %1</source>
        <translation>Die Zieldatei %1 konnte nicht geöffnet werden</translation>
    </message>
</context>
<context>
    <name>QAndroidImageEncoderControl</name>
    <message>
        <source>JPEG image</source>
        <translation>JPEG-Bild</translation>
    </message>
</context>
<context>
    <name>QAndroidMediaContainerControl</name>
    <message>
        <source>MPEG4 media file format</source>
        <translation>MPEG4-Medien-Dateiformat</translation>
    </message>
    <message>
        <source>3GPP media file format</source>
        <translation>3GPP-Medien-Dateiformat</translation>
    </message>
    <message>
        <source>AMR NB file format</source>
        <translation>AMR-NB-Dateiformat</translation>
    </message>
    <message>
        <source>AMR WB file format</source>
        <translation>AMR-WB-Dateiformat</translation>
    </message>
</context>
<context>
    <name>QAndroidVideoEncoderSettingsControl</name>
    <message>
        <source>H.263 compression</source>
        <translation>H.263-Kompression</translation>
    </message>
    <message>
        <source>H.264 compression</source>
        <translation>H.264-Kompression</translation>
    </message>
    <message>
        <source>MPEG-4 SP compression</source>
        <translation>MPEG-4-SP-Kompression</translation>
    </message>
</context>
<context>
    <name>QAudioDecoder</name>
    <message>
        <source>The QAudioDecoder object does not have a valid service</source>
        <translation>Das QAudioDecoder-Objekt hat keinen gültigen Dienst</translation>
    </message>
</context>
<context>
    <name>QCamera</name>
    <message>
        <source>The camera service is missing</source>
        <translation>Der Kameradienst fehlt</translation>
    </message>
</context>
<context>
    <name>QCameraImageCapture</name>
    <message>
        <source>Device does not support images capture.</source>
        <translation>Das Gerät unterstützt das Aufnehmen von Bildern nicht.</translation>
    </message>
</context>
<context>
    <name>QDeclarativeAudio</name>
    <message>
        <source>volume should be between 0.0 and 1.0</source>
        <translation>Lautstärke sollte zwischen 0.0 und 1.0 liegen</translation>
    </message>
</context>
<context>
    <name>QGstreamerAudioDecoderSession</name>
    <message>
        <source>Cannot play stream of type: &lt;unknown&gt;</source>
        <translation>Datenstrom des Typs &lt;unbekannt&gt; kann nicht abgespielt werden</translation>
    </message>
</context>
<context>
    <name>QGstreamerAudioEncode</name>
    <message>
        <source>Raw PCM audio</source>
        <translation>Raw-PCM-Audio</translation>
    </message>
</context>
<context>
    <name>QGstreamerAudioInputSelector</name>
    <message>
        <source>System default device</source>
        <translation>System-Vorgabegerät</translation>
    </message>
</context>
<context>
    <name>QGstreamerCameraControl</name>
    <message>
        <source>State not supported.</source>
        <translation>nicht unterstützter Zustand.</translation>
    </message>
</context>
<context>
    <name>QGstreamerCaptureSession</name>
    <message>
        <source>Could not create an audio source element</source>
        <translation>Das Audio-Quellelement konnte nicht erstellt werden</translation>
    </message>
    <message>
        <source>Failed to build media capture pipeline.</source>
        <translation>Es konnte keine Medien-Aufnahme-Pipeline erstellt werden.</translation>
    </message>
</context>
<context>
    <name>QGstreamerImageCaptureControl</name>
    <message>
        <source>Not ready to capture</source>
        <translation>Nicht aufnahmebereit</translation>
    </message>
</context>
<context>
    <name>QGstreamerImageEncode</name>
    <message>
        <source>JPEG image encoder</source>
        <translation>JPEG-Bild-Kodierer</translation>
    </message>
</context>
<context>
    <name>QGstreamerPlayerControl</name>
    <message>
        <source>Attempting to play invalid Qt resource</source>
        <translation>Es wurde versucht, eine ungültige Qt-Ressource abzuspielen</translation>
    </message>
    <message>
        <source>Attempting to play invalid user stream</source>
        <translation>Es wurde versucht, einen ungültigen Nutzer-Datenstrom abzuspielen</translation>
    </message>
</context>
<context>
    <name>QGstreamerPlayerSession</name>
    <message>
        <source>Cannot play stream of type: &lt;unknown&gt;</source>
        <translation>Datenstrom des Typs &lt;unbekannt&gt; kann nicht abgespielt werden</translation>
    </message>
    <message>
        <source>UDP source timeout</source>
        <translation>Zeitüberschreitung bei UDP-Quelle</translation>
    </message>
    <message>
        <source>Media is loaded as a playlist</source>
        <translation>Medien als Abspielliste geladen</translation>
    </message>
</context>
<context>
    <name>QGstreamerRecorderControl</name>
    <message>
        <source>Service has not been started</source>
        <translation>Der Dienst wurde nicht gestartet</translation>
    </message>
    <message>
        <source>Not compatible codecs and container format.</source>
        <translation>Keine kompatiblen Codecs und Container-Formate.</translation>
    </message>
</context>
<context>
    <name>QGstreamerVideoInputDeviceControl</name>
    <message>
        <source>Main camera</source>
        <translation>Hauptkamera</translation>
    </message>
    <message>
        <source>Front camera</source>
        <translation>Vordere Kamera</translation>
    </message>
</context>
<context>
    <name>QMediaPlayer</name>
    <message>
        <source>The QMediaPlayer object does not have a valid service</source>
        <translation>Das QMediaPlayer-Objekt hat keinen gültigen Dienst</translation>
    </message>
</context>
<context>
    <name>QMediaPlaylist</name>
    <message>
        <source>Could not add items to read only playlist.</source>
        <translation>Konnte keine Elemente zu schreibgeschützter Abspielliste hinzufügen</translation>
    </message>
    <message>
        <source>Playlist format is not supported</source>
        <translation>Nicht unterstütztes Format der Abspielliste</translation>
    </message>
    <message>
        <source>The file could not be accessed.</source>
        <translation>Es konnte nicht auf die Datei zugegriffen werden.</translation>
    </message>
    <message>
        <source>Playlist format is not supported.</source>
        <translation>Nicht unterstütztes Format der Abspielliste</translation>
    </message>
</context>
<context>
    <name>QMultimediaDeclarativeModule</name>
    <message>
        <source>CameraCapture is provided by Camera</source>
        <translation>CameraCapture wird von Camera bereitgestellt</translation>
    </message>
    <message>
        <source>CameraRecorder is provided by Camera</source>
        <translation>CameraRecorder wird von Camera bereitgestellt</translation>
    </message>
    <message>
        <source>CameraExposure is provided by Camera</source>
        <translation>CameraExposure wird von Camera bereitgestellt</translation>
    </message>
    <message>
        <source>CameraFocus is provided by Camera</source>
        <translation>CameraFocus wird von Camera bereitgestellt</translation>
    </message>
    <message>
        <source>CameraFlash is provided by Camera</source>
        <translation>CameraFlash wird von Camera bereitgestellt</translation>
    </message>
    <message>
        <source>CameraImageProcessing is provided by Camera</source>
        <translation>CameraImageProcessing wird von Camera bereitgestellt</translation>
    </message>
</context>
<context>
    <name>QPlaylistFileParser</name>
    <message>
        <source>%1 does not exist</source>
        <translation>%1 existiert nicht</translation>
    </message>
</context>
<context>
    <name>QPlaylistFileParserPrivate</name>
    <message>
        <source>%1 playlist type is unknown</source>
        <translation>Unbekannter Typ der Abspielliste %1</translation>
    </message>
    <message>
        <source>invalid line in playlist file</source>
        <translation>ungültige Zeile in Abspielliste</translation>
    </message>
    <message>
        <source>Empty file provided</source>
        <translation>Leere Datei angegeben</translation>
    </message>
</context>
</TS>
